@@ -254,8 +254,8 @@ render <- function(input,
   output_dir <- dirname(output_file)
 
   # use output filename based files dir
-  files_dir <- file.path(output_dir, knitr_files_dir(basename(output_file)))
-  files_dir <- pandoc_path_arg(files_dir)
+  files_dir_slash <- file.path(output_dir, knitr_files_dir(basename(output_file)))
+  files_dir <- pandoc_path_arg(files_dir_slash)
 
   # default to no cache_dir (may be generated by the knit)
   cache_dir <- NULL
@@ -363,8 +363,10 @@ render <- function(input,
     # use filename based figure and cache directories
     base_pandoc_to <- gsub('[-+].*', '', pandoc_to)
     if (base_pandoc_to == 'html4') base_pandoc_to <- 'html'
-    figures_dir <- paste(files_dir, "/figure-", base_pandoc_to, "/", sep = "")
-    knitr::opts_chunk$set(fig.path = figures_dir)
+    knitr::opts_chunk$set(fig.path = paste0(
+      pandoc_path_arg(files_dir_slash, backslash = FALSE),
+      "/figure-", base_pandoc_to, "/"
+    ))
     cache_dir <- knitr_cache_dir(input, base_pandoc_to)
     knitr::opts_chunk$set(cache.path = cache_dir)
 
