@@ -223,8 +223,7 @@ merge_lists <- function(base_list, overlay_list, recursive = TRUE) {
   }
 }
 
-strip_white <- function(x)
-{
+strip_white <- function(x) {
   if (!length(x))
     return(x)
   while (is_blank(x[1])) {
@@ -240,8 +239,7 @@ strip_white <- function(x)
   x
 }
 
-is_blank <- function(x)
-{
+is_blank <- function(x) {
   if (length(x))
     all(grepl("^\\s*$", x))
   else TRUE
@@ -312,167 +310,8 @@ escape_regex_metas <- function(in_str) {
   gsub("([.\\|()[{^$+?])", "\\\\\\1", in_str)
 }
 
-# call latexmk to compile tex to PDF; if not available, use a simple emulation
 latexmk <- function(file, engine, biblatex = FALSE) {
-  if (requireNamespace('tinytex', quietly = TRUE)) {
-    return(tinytex::latexmk(file, engine, if (biblatex) 'biber' else 'bibtex'))
-  }
-  message('You are recommended to install the tinytex package to build PDF.', call. = FALSE)
-  if (!grepl('[.]tex$', file))
-    stop("The input file '", file, "' does not appear to be a LaTeX document")
-  engine <- find_latex_engine(engine)
-  latexmk_path <- find_program('latexmk')
-  if (latexmk_path == '') {
-    # latexmk not found
-    latexmk_emu(file, engine, biblatex)
-  } else if (find_program('perl') != '' && latexmk_installed(latexmk_path)) {
-    system2_quiet(latexmk_path, c(
-      '-pdf -latexoption=-halt-on-error -interaction=batchmode',
-      paste0('-pdflatex=', shQuote(engine)), shQuote(file)
-    ), error = {
-      check_latexmk_version(latexmk_path)
-      show_latex_error(file)
-    })
-    system2(latexmk_path, '-c', stdout = FALSE)  # clean up nonessential files
-  } else {
-    latexmk_emu(file, engine, biblatex)
-  }
-}
-
-# a quick and dirty version of latexmk (should work reasonably well unless the
-# LaTeX document is extremely complicated)
-latexmk_emu <- function(file, engine, biblatex = FALSE) {
-  owd <- setwd(dirname(file))
-  on.exit(setwd(owd), add = TRUE)
-  # only use basename because bibtex may not work with full path
-  file <- basename(file)
-
-  file_with_same_base <- function(file) {
-    files <- list.files()
-    files <- files[utils::file_test('-f', files)]
-    base <- tools::file_path_sans_ext(file)
-    normalizePath(files[tools::file_path_sans_ext(files) == base])
-  }
-  # clean up aux files from LaTeX compilation
-  files1 <- file_with_same_base(file)
-  keep_log <- FALSE
-  on.exit(add = TRUE, {
-    files2 <- file_with_same_base(file)
-    files3 <- setdiff(files2, files1)
-    aux <- c(
-      'aux', 'log', 'bbl', 'blg', 'fls', 'out', 'lof', 'lot', 'idx', 'toc',
-      'nav', 'snm', 'vrb', 'ilg', 'ind'
-    )
-    if (keep_log) aux <- setdiff(aux, 'log')
-    unlink(files3[tools::file_ext(files3) %in% aux])
-  })
-
-  fileq <- shQuote(file)
-  run_engine <- function() {
-    system2_quiet(engine, c('-halt-on-error -interaction=batchmode', fileq), error = {
-      keep_log <<- TRUE
-      show_latex_error(file)
-    })
-  }
-  run_engine()
-  # generate index
-  idx <- sub('[.]tex$', '.idx', file)
-  if (file.exists(idx)) {
-    system2_quiet(find_latex_engine('makeindex'), shQuote(idx), error = {
-      stop("Failed to build the index via makeindex", call. = FALSE)
-    })
-  }
-  # generate bibliography
-  if (biblatex) {
-    aux_ext <- '.bcf'
-    bib_engine <- 'biber'
-  } else {
-    aux_ext <- '.aux'
-    bib_engine <- 'bibtex'
-  }
-  aux <- sub('[.]tex$', aux_ext, file)
-  if (file.exists(aux)) {
-    if (biblatex || require_bibtex(aux))
-      system2_quiet(find_latex_engine(bib_engine), shQuote(aux), error = {
-        stop("Failed to build the bibliography via ", bib_engine, call. = FALSE)
-      })
-  }
-  run_engine()
-  run_engine()
-}
-
-require_bibtex <- function(aux) {
-  x <- readLines(aux)
-  r <- length(grep('^\\\\citation\\{', x)) && length(grep('^\\\\bibdata\\{', x)) &&
-    length(grep('^\\\\bibstyle\\{', x))
-  if (r && is_windows()) tweak_aux(aux, x)
-  r
-}
-
-# remove the .bib extension in \bibdata{} in the .aux file, because bibtex on
-# Windows requires no .bib extension (sigh)
-tweak_aux <- function(aux, x = readLines(aux)) {
-  r <- '^\\\\bibdata\\{.+\\}\\s*$'
-  if (length(i <- grep(r, x)) == 0) return()
-  x[i] = gsub('[.]bib([,}])', '\\1', x[i])
-  writeLines(x, aux)
-}
-
-system2_quiet <- function(..., error = NULL) {
-  # run the command quietly if possible
-  res <- system2(..., stdout = FALSE, stderr = FALSE)
-  # if failed, use the normal mode
-  if (res != 0) res <- system2(...)
-  # if still fails, run the error callback
-  if (res != 0) error  # lazy evaluation
-  invisible(res)
-}
-
-# parse the LaTeX log and show error messages
-show_latex_error <- function(file) {
-  logfile <- file_with_ext(file, 'log')
-  e <- c('Failed to compile ', file, '.')
-  if (!file.exists(logfile)) stop(e, call. = FALSE)
-  x <- readLines(logfile, warn = FALSE)
-  b <- grep('^\\s*$', x)  # blank lines
-  m <- NULL
-  for (i in grep('^! ', x)) {
-    # ignore the last error message about the fatal error
-    if (grepl('==> Fatal error occurred', x[i], fixed = TRUE)) next
-    n <- b[b > i]
-    n <- if (length(n) == 0) i else min(n) - 1L
-    m <- c(m, x[i:n], '')
-  }
-  if (length(m)) {
-    message(paste(m, collapse = '\n'))
-    stop(e, ' See ', logfile, ' for more info.', call. = FALSE)
-  }
-}
-
-# check if latexmk was correctly installed; see more info at
-# https://github.com/rstudio/bookdown/issues/121
-latexmk_installed <- function(latexmk_path) {
-  if (system2_quiet(latexmk_path, '-v') == 0) return(TRUE)
-  warning('The LaTeX package latexmk was not correctly installed.', call. = FALSE)
-  if (!is_windows()) return(FALSE)
-  shell('latexmk -v')  # hopefully MiKTeX can fix it automatically
-  system2_quiet(latexmk_path, '-v') == 0
-}
-
-# check the version of latexmk
-check_latexmk_version <- function(latexmk_path = find_program('latexmk')) {
-  out <- system2(latexmk_path, '-v', stdout = TRUE)
-  reg <- '^.*Version (\\d+[.]\\d+).*$'
-  out <- grep(reg, out, value = TRUE)
-  if (length(out) == 0) return()
-  ver <- as.numeric_version(gsub(reg, '\\1', out[1]))
-  if (ver >= '4.43') return()
-  system2(latexmk_path, '-v')
-  warning(
-    'Your latexmk version seems to be too low. ',
-    'You may need to update the latexmk package or your LaTeX distribution.',
-    call. = FALSE
-  )
+  tinytex::latexmk(file, engine, if (biblatex) 'biber' else 'bibtex')
 }
 
 n_bytes <- function(string) {
